import java.io.BufferedWriter;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStreamWriter;


public class VMWriter {
	
	
private FileWriter vmFile;
    


    public VMWriter(String basename) {
	 try {
	    vmFile = new FileWriter(basename + ".vm");
	 } catch (IOException e) {
	    e.printStackTrace();
	    System.exit(1);
	 }
	}

	

    // Write a sequence of VM code to the XML file.
    public void write(String code) {
	try {
	    vmFile.write(code+'\n');
	} catch (IOException e) {
	    e.printStackTrace();
	    System.exit(1);
	}
    }

    public void close() {
	try {
	    vmFile.close();
	} catch (IOException e) {
	    e.printStackTrace();
	    System.exit(1);
	}
    }
	

	
	public void writePush(Segment segment, int index){
		switch(segment){
		case ARG: write("push argument " + index); break;
		case STATIC: write("push static " + index); break;
		case THIS: write("push this " + index); break;
		case THAT: write("push that " + index); break;
		case CONST: write("push constant " + index); break;
		case LOCAL: write("push local " + index); break;
		case POINTER: write("push pointer " + index); break;
		case TEMP: write("push temp " + index); break;
		}
	}
	
	public void writePop(Segment segment, int index){
		switch(segment){
		case ARG: write("pop argument " + index); break;
		case STATIC: write("pop static " + index); break;
		case THIS: write("pop this " + index); break;
		case THAT: write("pop that " + index); break;
		case CONST: write("pop constant " + index); break;
		case LOCAL: write("pop local " + index); break;
		case POINTER: write("pop pointer " + index); break;
		case TEMP: write("pop temp " + index); break;
		}
	} 
	
	public void writeArtithmetic(char command){
		switch(command){
		case '+': write("add"); break;
		case '-': write("sub"); break;
		case '*': write("call Math.multiply 2"); break;
		case '/': write("call Math.divide 2"); break;
		case '<': write("lt"); break;
		case '>': write("gt"); break;
		case '&': write("and"); break;
		case '|': write("or"); break;
		case '=': write("eq"); break;
		}
	}

	public void writeCall(String name, int nArgs){
		write ("call "+name + " "+ nArgs);
	}
	
	public void writeFunction(String name, int nLocals){
		write ("function "+name + " "+ nLocals);
	}
	
	public void writeReturn(){
		write ("return");
	}
}
